mcpField

Skills

98,067 packaged capabilities and playbooks for agents. Install any of them with one command.

Development

M
mini-wiki
mini-wiki
trsoliu / mini-wiki

Build and maintain a professional, source-traceable project knowledge network. Use when the user asks to generate, update, validate, search, migrate, or open a project Wiki; when architecture and module knowledge should be connected; or when Obsidian-compatible Properties, Bases, and Canvas views are useful. Durable Markdown lives in wiki/ and remains usable without Obsidian.

Development302
M
ms-teams-apps
ms-teams-apps
alinaqi / maggy

Microsoft Teams bots and AI agents - Claude/OpenAI, Adaptive Cards, Graph API

Development302
O
OpenAI Apps MCP
OpenAI Apps MCP
jezweb / claude-skills

Build ChatGPT apps with MCP servers on Cloudflare Workers. Extend ChatGPT with custom tools and interactive widgets (HTML/JS UI). Use when: developing ChatGPT extensions, implementing MCP servers, or troubleshooting CORS, widget 404s, MIME types, ASSETS binding errors, Next.js integration issues, or edge platform limitations.

Development302
P
pr-review-loop
pr-review-loop
xpepper / pr-review-agent-skill

Use when addressing open PR review comments from any reviewer (human or bot). Runs an in-session loop by default; on an explicit `--handoff` request, completes one unit of work per session and stops so the user starts the next. When an external shell loop should drive the sessions instead of the user, use ralph-wiggum-loop.

Testing & quality302
R
regex-visual-debugger
regex-visual-debugger
onewave-ai / claude-skills

Debug regex patterns with visual breakdowns, plain English explanations, test case generation, and flavor conversion. Use when the user needs help with regular expressions or pattern matching

Development302
S
seo-technical
seo-technical
rampstackco / claude-skills

Run a comprehensive technical SEO audit covering crawlability, indexability, rendering, site architecture, structured data, page experience, security, and internationalization. Use this skill whenever the user asks about technical SEO, crawl issues, indexing problems, sitemaps, robots.txt, canonical tags, schema markup, page speed, Core Web Vitals, hreflang, redirects, or site-wide search performance. Triggers on technical SEO, site audit, crawlability, indexability, sitemap, robots.txt, canonical, redirect chain, schema, JSON-LD, Core Web Vitals, page speed, hreflang, mobile usability, HTTPS, security headers, render-blocking, JavaScript SEO. Also triggers when a site has indexing problems, traffic drops, or migration concerns, even if 'technical SEO' is not said explicitly.

Marketing & growth302
S
sveltia-cms
sveltia-cms
jezweb / claude-skills

Set up Sveltia CMS, a lightweight Git-backed CMS successor to Decap/Netlify CMS (300KB bundle, 270+ fixes). Framework-agnostic for Hugo, Jekyll, 11ty, and Astro. Prevents 10 documented errors. Use when adding a CMS to static sites, migrating from Decap CMS, or fixing OAuth, YAML parse, datetime timezone, GDPR font loading, or CORS/COOP errors

Development302
W
wts-expert
wts-expert
desplega-ai / ai-toolbox

Git worktree management expert for @desplega.ai/wts. Use when the user asks about git worktrees, wts commands, worktree workflows, or wants help managing multiple branches simultaneously.

Development302
A
adopt-c-bounds-safety
adopt-c-bounds-safety
tartinerlabs / skills

Guide for the C -fbounds-safety language extension. Covers the language model, pointer annotations, adopting bounds-safety in existing C code, compiler build settings and modes, and runtime debugging of bounds violations.

Development301
A
api-contract-review
api-contract-review
decebals / claude-code-java

Review REST API contracts for HTTP semantics, versioning, backward compatibility, and response consistency. Use when the user asks “review API”, “check endpoints”, “REST review”, or before releasing API changes.

Testing & quality301
A
appstore-connect
appstore-connect
melvynx / aiblueprint

Drive App Store Connect through the asc CLI for apps, builds, TestFlight, reviews, sales, metadata, IAP, signing, and submissions. Use for “check my app”, “App Store Connect”, “TestFlight”, “app review”, “my app sales”, or “asc”.

Cloud & DevOps301
C
chezmoi-workflows
chezmoi-workflows
terrylica / cc-skills

Dotfile backup and sync with chezmoi. TRIGGERS - chezmoi, dotfiles, sync dotfiles, backup configs, cross-machine sync.

Development301
C
commit
commit
casper-studios / casper-marketplace

Generate commit messages following conventional commits and commit staged changes. Use when creating commits or when user invokes /commit.

Development301
C
creating-an-endpoint
creating-an-endpoint
posthog / skills

Create a PostHog endpoint with the right shape on the first try — covers query kind choice, name conventions, what to expose as variables (HogQL code_name vs insight breakdown), data_freshness_seconds, and whether to materialise on day one. Use when the user says "create an endpoint", "expose this query as an API", "turn this insight into an endpoint", or asks for help structuring a new endpoint. Steers away from common mistakes: materialising a query with cohort breakdowns or an ineligible compare query, inline-only variables on a materialised endpoint, unbounded date ranges, ambiguous names.

Data & databases301
C
curl-command-generator
curl-command-generator
patricio0312rev / skills

Generates ready-to-run cURL commands from Express, Next.js, Fastify, or other API routes. Creates copy-paste commands with proper headers, authentication, and request bodies. Use when users request "generate curl commands", "curl examples", "api curl", or "command line api testing".

Development301
D
database-schema
database-schema
alinaqi / maggy

Schema awareness - read before coding, type generation, prevent column errors

Data & databases301
G
generate2dmap
generate2dmap
0x0funky / agent-sprite-forge

Plan and build 2D game maps and scenes - top-down and side-scrolling levels, tilemaps, prop packs, parallax backgrounds and HD-2D battle or story plates - with collision, navigation and reachability checks, environment motion, a playable HTML preview and export to Tiled, Godot 4 or LDtk. Map art (terrain, tiles, props, plates, parallax layers) is image generation by default, through generate2dmedia route_media.py (the API when a key is configured, else the local Codex or Grok CLI); map data (layout, collision, exits, spawns) is written as data. Use for any map, level, room, scene, background, terrain or prop-kit request. Not for characters, creatures, items or FX (generate2dsprite), character animation (video2dsprite), code-drawn tiles or maps (codeart2d, only on request) or calling an image or video API by itself (generate2dmedia)

Creative & media301
G
gh-address-comments
gh-address-comments
davila7 / claude-code-templates

Help address review/issue comments on the open GitHub PR for the current branch using gh CLI; verify gh auth first and prompt the user to authenticate if not logged in.

Development301
G
godot-genre-idle-clicker
godot-genre-idle-clicker
thedivergentai / game-design-agentic-skills

Expert blueprint for idle/clicker games including big number handling (mantissa + exponent system), exponential growth curves (cost_growth_factor 1.15x), generator systems (auto-producers), offline progress calculation, prestige systems (reset for permanent multipliers), number formatting (K/M/B suffixes, scientific notation). Use for incremental games, idle games, or cookie clicker derivatives. Trigger keywords: idle_game, big_number, exponential_growth, generator_system, offline_progress, prestige_system, number_formatting.

Development301
G
godot-genre-tower-defense
godot-genre-tower-defense
thedivergentai / game-dev-agentic-skills

Expert blueprint for tower defense games (Bloons TD, Kingdom Rush, Fieldrunners) covering wave management, tower targeting logic, path algorithms, economy balance, and mazing mechanics. Use when building TD, lane defense, or tower placement strategy games. Keywords tower defense, wave spawner, pathfinding, targeting priority, mazing, NavigationServer baking.

Development301
G
godot-platform-web
godot-platform-web
thedivergentai / game-dev-agentic-skills

Expert blueprint for HTML5/web export on Compatibility (WebGL 2.0): JavaScriptBridge, localStorage wrapper, custom loading shells, COOP/COEP hosts, relative paths, beforeunload, visibility pause, and size optimization. WebGPU is out of scope. Keywords: web, HTML5, WebGL, Compatibility, JavaScriptBridge, localStorage, COOP, COEP, canvas, browser API.

Development301
H
Hook Development
Hook Development
davila7 / claude-code-templates

Use when the user asks to “create a hook,” “add a PreToolUse/PostToolUse/Stop hook,” “validate tool use,” “implement prompt-based hooks,” “use ${CLAUDE_PLUGIN_ROOT},” “set up event-driven automation,” “block dangerous commands,” or mentions hook events (PreToolUse, PostToolUse, Stop, SubagentStop, SessionStart, SessionEnd, UserPromptSubmit, PreCompact, Notification). Provides comprehensive guidance for creating and implementing Claude Code plugin hooks, focusing on the advanced prompt-based hooks API

Agent workflows301
M
manage-app
manage-app
twentyhq / twenty

Use when the user wants to manage or troubleshoot tooling, remotes, sync, build, deploy, logs, CI/CD, or operational workflows for an existing Twenty app.

Cloud & DevOps301
P
page-layout-builder
page-layout-builder
patricio0312rev / skills

Generates complete page layouts and shells for common patterns (dashboard, authentication, settings, CRUD pages) with consistent navigation, layout components, routing structure, and state management placeholders. Use when building "new page", "dashboard layout", "auth pages", or "admin panel structure".

Design & UI301
S
scenario-unreal-world-building
scenario-unreal-world-building
scenario-labs / skills

Use when building or fixing an Unreal Engine 5 level or open world: World Partition, OFPA, Data Layers, Level Instances, Packed Level Actors, HLOD, landscape size, heightmap import or clipping, edit layers, terrain material rules, foliage and grass, a PCG forest or rock scatter, runtime GPU grass, Nanite and tessellation choices, modular kits, a river or village, streaming pop-in, cells not loading, landscape black spots, "PCG shows nothing in the editor", or a world too heavy to hand to lighting.

Creative & media301
S
specsfy-specialist-interface-experience
specsfy-specialist-interface-experience
promovaweb / specsfy

Analisar o sistema atual e orientar a descoberta, o plano e a entrega de interfaces completas, bonitas e compatíveis com a stack existente.

Design & UI301
S
swiftui-whats-new-27
swiftui-whats-new-27
tartinerlabs / skills

New SwiftUI APIs, behaviors, and deprecations in the 2027 OS releases (iOS 27 and aligned macOS/watchOS/tvOS/visionOS). Consult when asked what's new in SwiftUI 27, or when working with: - @State compile errors after an SDK update ("used before being initialized", "invalid redeclaration of synthesized property") or @State becoming a macro - @ViewBuilder/@ContentBuilder ambiguous overloads or type-check regressions; drag-to-reorder in any container (List, stacks, grids, custom layouts) via reorderable()/reorderContainer and its drag-and-drop - AsyncImage caching, reloading on scroll, or a custom URLSession - Swipe actions outside List (ScrollView, LazyVStack, LazyVGrid) via swipeActions()/swipeActionsContainer() - Toolbar overflow, visibility (visibilityPriority, ToolbarOverflowMenu, toolbarMinimizeBehavior), and pinning - Presenting a confirmationDialog or alert from an optional item binding

Development301
T
triton-lang
triton-lang
mohitmishra786 / low-level-dev-skills

Triton language skill for Python GPU kernel authoring. Use when writing Triton kernels with @triton.jit, tl.load/store, masking, and atomics; benchmarking with triton.testing; or integrating kernels into PyTorch. Activates on queries about Triton, tl.constexpr, block pointers, Triton benchmarking, or PyTorch custom ops.

Development301
U
uikit-app-modernization
uikit-app-modernization
tartinerlabs / skills

Modernizes UIKit apps for multi-window environments by replacing legacy shared-state APIs with context-appropriate modern alternatives. This includes references to mainScreen, interfaceOrientation, application and scene lifecycle, as well as safe area inset updates.

Development301
V
vercel-composition-patterns
vercel-composition-patterns
guanyang / open-agent-hub

React composition patterns that scale. Use when refactoring components with boolean prop proliferation, building flexible component libraries, or designing reusable APIs. Triggers on tasks involving compound components, render props, context providers, or component architecture. Includes React 19 API changes.

Development301
V
vercel-react-best-practices
vercel-react-best-practices
guanyang / open-agent-hub

React and Next.js performance optimization guidelines from Vercel Engineering. This skill should be used when writing, reviewing, or refactoring React/Next.js code to ensure optimal performance patterns. Triggers on tasks involving React components, Next.js pages, data fetching, bundle optimization, or performance improvements.

Development301
W
wevu-best-practices
wevu-best-practices
sonofmagic / skills

A best-practices guide for the wevu runtime in mini-programs, covering lifecycle registration, reactive updates, JSX/TSX, event contracts, `bindModel/useBindModel`, layout, native router helpers, `wevu/router`, store constraints, and performance management for `setData` scheduling, rendering, page transitions, resources, and memory.

Development301
A
authoritative-server
authoritative-server
decentraland / sdk-skills

Build multiplayer Decentraland scenes with a headless Multiplayer Server. Use when the user wants authoritative multiplayer, anti-cheat, server-side validation, persistent storage, or server messages. Do NOT use for basic CRDT multiplayer without a server (see multiplayer-sync)

Development300
B
basecamp-doctor
basecamp-doctor
basecamp / skills

Diagnose Basecamp CLI, authentication, and agent-plugin health

Development300
B
build
build
thedotmack / claude-mem

Fully automate a coding task with make-plan, do, and babysit.

Agent workflows300
C
commerce-app-admin-ui
commerce-app-admin-ui
adobe / skills

Add or modify Adobe Commerce Admin UI extensions on the commerce/backend-ui/2 extension point: custom grid columns, mass actions, order view buttons, a custom Admin menu entry, and custom ACL resources. Use whenever the user wants to extend the Commerce Admin — add a column to the order, product, or customer grid, add a bulk/mass action to a grid, add a button to the order view page, add a custom menu item or page, or declare custom permissions the app checks itself — even when they don't name the extension point.

Development300
C
cost-estimate
cost-estimate
ulpi-io / skills

Estimate what a codebase, branch diff, or single commit would COST to build — evidence-driven, not a guess: measure the real scope with the helper scripts (LOC counter + git session analyzer), classify every source line into one productivity bucket, run the cost calculator for engineering hours, organizational overhead, calendar and team-cost views plus Claude ROI, and sanity-check the effective lines/hour — runs as a forked analysis workflow with its own reasoning budget, isolated from the main flow. Keeps raw engineering hours separate from overhead and team multipliers, never presents a number without scope, assumptions, and a confidence level, and never claims region-specific market rates unless the user asked and that research was actually done. Use when the user asks to estimate development cost, effort, engineering hours, or ROI.

Development300
D
document-generate
document-generate
garrytan / gstack

Generate missing documentation from scratch for a feature, module, or entire project. (gstack)

Development300
D
drupal-frontend
drupal-frontend
omedia / drupal-skill

Drupal front-end specialist skill for theme development, Twig templates, and the rendering system (Drupal 8–11+). Use when working with Drupal themes, Twig syntax, preprocessing, CSS/JS libraries, or template suggestions.

Design & UI300
E
eve-bootstrap
eve-bootstrap
incept5 / eve-skillpacks

Full onboarding flow — detects auth state, handles access requests for new users, and sets up project for all users.

Cloud & DevOps300
F
fastapi-templates
fastapi-templates
sickn33 / agentic-awesome-skills

Create production-ready FastAPI projects with async patterns, dependency injection, and comprehensive error handling. Use when building new FastAPI applications or setting up backend API projects.

Development300
F
find-rules
find-rules
pedronauck / skills

Discover and understand project rules, coding standards, and architectural guidelines before starting a task. Use when you need to know the constraints, patterns, or compliance requirements for a feature, file, or technology.

Agent workflows300
F
fullstack-guardian
fullstack-guardian
farmage / opencode-skills

Builds security-focused full-stack web applications by implementing integrated frontend and backend components with layered security at every level. Covers the complete stack from database to UI, enforcing auth, input validation, output encoding, and parameterized queries across all layers. Use when implementing features across frontend and backend, building REST APIs with corresponding UI, connecting frontend components to backend endpoints, creating end-to-end data flows from database to UI, or implementing CRUD operations with UI forms. Distinct from frontend-only, backend-only, or API-only skills in that it simultaneously addresses all three perspectives—Frontend, Backend, and Security—within a single implementation workflow. Invoke for full-stack feature work, web app development, authenticated API routes with views, microservices, real-time features, monorepo architecture, or technology selection decisions.

Development300
M
meteor-pubsub
meteor-pubsub
meteor / agent-skills

Use when authoring or debugging Meteor publications and subscriptions (Meteor.publish, Meteor.subscribe). Triggers on publication strategies (SERVER_MERGE, NO_MERGE, NO_MERGE_NO_HISTORY), the low-level publish API (added/changed/removed), cursor authorization, reactive joins, leaked documents. Use this skill when the user asks about pub/sub or asks about reactive data fetching.

Development300
M
microservices-patterns
microservices-patterns
sickn33 / agentic-awesome-skills

Master microservices architecture patterns, including service boundaries, inter-service communication, data management, and resilience patterns for building distributed systems.

Development300
M
mpi
mpi
mohitmishra786 / low-level-dev-skills

MPI skill for distributed-memory parallel programming. Use when writing MPI_Send/Recv programs, collective operations, non-blocking communication, MPI+OpenMP hybrid programs, or debugging with mpirun. Activates on queries about MPI_Init, MPI_Allreduce, MPI_Isend, mpirun, MPI-IO, or MPI performance.

Development300
N
neovim
neovim
julianobarbosa / claude-code-skills

Comprehensive guide for this Neovim configuration, a modular, performance-optimized, Lua-based IDE. Use when configuring plugins, adding keybindings, setting up LSP servers, debugging, or extending the configuration. Covers lazy.nvim, 82+ plugins across 9 categories, DAP debugging, AI integrations, and performance optimization.

Development300
P
plugin-creator
plugin-creator
openai / plugins

Create and scaffold plugin directories for Codex with a required `.codex-plugin/plugin.json`, optional plugin folders/files, and baseline placeholders you can edit before publishing or testing. Use when Codex needs to create a new personal plugin, add optional plugin structure, or generate or update personal or repo-root `.agents/plugins/marketplace.json` entries for plugin ordering and availability metadata.

Agent workflows300
P
protocol-reverse-engineering
protocol-reverse-engineering
sickn33 / agentic-awesome-skills

Comprehensive techniques for capturing, analyzing, and documenting network protocols for security research, interoperability, and debugging

Security300
R
readme-generator
readme-generator
patricio0312rev / skills

Generates comprehensive README files with badges, installation, usage, API docs, and contribution guidelines. Use when users request "README", "project documentation", "readme template", "documentation generator", or "project setup docs".

Development300
R
requirements-clarity
requirements-clarity
pedronauck / skills

Clarify ambiguous requirements through focused dialogue before implementation. Use when requirements are unclear, features are complex (>2 days), or involve cross-team coordination. Ask two core questions - Why? (YAGNI check) and Simpler? (KISS check) - to ensure clarity before coding.

Development300
R
riscv-privileged
riscv-privileged
mohitmishra786 / low-level-dev-skills

RISC-V privileged architecture skill for M/S/U modes and traps. Use when handling CSRs, trap handlers, PLIC/CLINT interrupts, OpenSBI integration, page tables Sv39/Sv48, or QEMU virt testing. Activates on queries about RISC-V privileged, mstatus, mtvec, satp, OpenSBI, PLIC, or Sv39.

Development300
S
signals-scout-error-tracking
signals-scout-error-tracking
posthog / skills

Signals scout for PostHog error tracking. Watches `$exception` bursts, stuck loops, multi- fingerprint clusters, and status regressions.

Development300
S
syncfusion-angular-data-manager
syncfusion-angular-data-manager
syncfusion / angular-ui-components-skills

Implements Syncfusion Angular DataManager for local/remote binding, CRUD, querying, caching, and middleware. Supports JsonAdaptor, ODataAdaptor, ODataV4Adaptor, UrlAdaptor, WebApiAdaptor, WebMethodAdaptor, RemoteSaveAdaptor, GraphQLAdaptor, CustomDataAdaptor, and CustomAdaptor. Covers Query class, filtering, sorting, paging, grouping, persistence, offline mode, caching, and error handling.

Data & databases300
U
uv-tool-management
uv-tool-management
laurigates / claude-plugins

Install and manage global Python CLI tools with uv (pipx alternative). Use when the user mentions uv tool, uvx, installing CLI tools globally, or pipx replacement.

Development300
W
weapp-vite-vue-sfc-best-practices
weapp-vite-vue-sfc-best-practices
sonofmagic / skills

A Vue SFC best-practices guide for mini-program projects using weapp-vite, covering script setup, template-only SFCs, JSON macros, `definePageMeta`/layout, `defineModel`, `usingComponents`, built-in i18n Behavior, JSX/TSX script blocks, template directive compatibility, multi-platform SFCs, `.weapp-vite` type support files, and the managed `prepare` workflow.

Development300
A
add-office365
add-office365
microsoft / power-platform-skills

Adds Office 365 Outlook connector to a Power Apps code app. Use when accessing calendars, sending emails, reading inbox, or managing Outlook events.

Productivity299
B
bitrix-database
bitrix-database
bxmaximum / bitrix-framework-skills

D7 Connection, SqlHelper, SqlExpression placeholders, raw SQL, upserts, transactions, named locks, DDL builders, SqlTracker. Use when ORM is not enough: bulk SQL, reports, extra connections, schema changes, query debugging.

Data & databases299
C
certified-variables
certified-variables
dfinity / icskills

Serve cryptographically verified responses from query calls using Merkle trees and subnet BLS signatures. Covers the certified data API, RbTree/CertTree construction, witness generation, HTTP response certification for custom http_request canisters (ic-http-certification), and frontend certificate validation (@dfinity/certificate-verification). Use when query responses need verification, certified data, or response authenticity proofs. For static frontends served by the certified-assets canister, use the static-site skill instead: certification is automatic there.

Security299
C
code-refactor
code-refactor
mhattingpete / claude-skills-marketplace

Perform bulk code refactoring operations like renaming variables/functions across files, replacing patterns, and updating API calls. Use when users request renaming identifiers, replacing deprecated code patterns, updating method calls, or making consistent changes across multiple locations

Development299
10741–10800 of 37,547

New to MCP?

From what the protocol is to installing your first server, these answers cover most first questions.

An open protocol that defines how AI applications connect to external tools and data in a uniform way. Clients talk to the model; MCP servers provide tools, resources and prompt templates. They exchange standard messages, so one server can be reused by many clients.